==> haskell-xml-hamlet-0.5.0.2-320-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-xml-hamlet.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 xml-hamlet
version:              0.5.0.2
visibility:           public
id:                   xml-hamlet-0.5.0.2-2SRaI3vQJQXCMkV09imAGG
key:                  xml-hamlet-0.5.0.2-2SRaI3vQJQXCMkV09imAGG
license:              BSD-3-Clause
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             http://www.yesodweb.com/
synopsis:             Hamlet-style quasiquoter for XML content
description:          Hamlet-style quasiquoter for XML content
category:             Text
abi:                  3df12a1536d91f3d1891993056cac2b0
exposed:              True
exposed-modules:      Text.Hamlet.XML
hidden-modules:       Text.Hamlet.XMLParse
import-dirs:          /usr/lib/ghc-9.4.8/site-local/xml-hamlet-0.5.0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/xml-hamlet-0.5.0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/xml-hamlet-0.5.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-xml-hamlet
hs-libraries:         HSxml-hamlet-0.5.0.2-2SRaI3vQJQXCMkV09imAGG
depends:
    base-4.17.2.1 containers-0.6.7 parsec-3.1.16.1
    shakespeare-2.1.4-FrhAShvdqrUCAuYjFw7ViB template-haskell-2.19.0.0
    text-2.0.2 xml-conduit-1.9.1.4-4urrQIvbdWCDFLffjLeesb

haddock-interfaces:   /usr/share/doc/haskell-xml-hamlet/html/xml-hamlet.haddock
haddock-html:         /usr/share/doc/haskell-xml-hamlet/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-xml-hamlet-0.5.0.2-322-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-xml-hamlet.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 xml-hamlet
version:              0.5.0.2
visibility:           public
id:                   xml-hamlet-0.5.0.2-C4oCuFuZ4zoE58cxWsZovd
key:                  xml-hamlet-0.5.0.2-C4oCuFuZ4zoE58cxWsZovd
license:              BSD-3-Clause
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             http://www.yesodweb.com/
synopsis:             Hamlet-style quasiquoter for XML content
description:          Hamlet-style quasiquoter for XML content
category:             Text
abi:                  a480b6d7ed7701390b592a78d291e864
exposed:              True
exposed-modules:      Text.Hamlet.XML
hidden-modules:       Text.Hamlet.XMLParse
import-dirs:          /usr/lib/ghc-9.4.8/site-local/xml-hamlet-0.5.0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/xml-hamlet-0.5.0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/xml-hamlet-0.5.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-xml-hamlet
hs-libraries:         HSxml-hamlet-0.5.0.2-C4oCuFuZ4zoE58cxWsZovd
depends:
    base-4.17.2.1 containers-0.6.7 parsec-3.1.16.1
    shakespeare-2.1.4-6V5ZmozK9yME8YZoiA8pEv template-haskell-2.19.0.0
    text-2.0.2 xml-conduit-1.9.1.4-HZKzsMGpoYKGE5hBj7zsBz

haddock-interfaces:   /usr/share/doc/haskell-xml-hamlet/html/xml-hamlet.haddock
haddock-html:         /usr/share/doc/haskell-xml-hamlet/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
